```
Usage: vcd disk update [OPTIONS] <name>

Options:
  -n, --new-name <name>           New name of the disk
  -s, --size <size>               New size of the disk in bytes
  -d, --description <description>
                                  New Description of the disk
  -S, --storage-profile <name>    Name of the new Storage Profile to be used
                                  for the disk.
  -i, --iops <iops>               New iops requirement of the disk
  -h, --help                      Show this message and exit.

```
